@@ -564,7 +564,7 @@ for devicename in devicenames:
         complete_success &= render_config(devicename, inventory, env,
                                           output_filename, no_output,
                                           no_squash_blanklines, dump_device,
-                                          debug, vars)
+                                          debug, **vars)
 
     except helpers.HelperBaseException as e:
         # one of the explicit helper exceptions has occurred
@@ -577,7 +577,7 @@ for devicename in devicenames:
         if raise_exception:
             raise
 
-        print("error:", e)
+        print("error:", e, file=sys.stderr)
 
 
         # since something went wrong, we don't have 'complete success'
